/**
 * 数据类型常量定义
 * 集中管理所有数据类型相关的常量，避免硬编码
 */

// 数据类型代码
export const DATA_TYPE = {
  // 餐饮油烟相关
  RESTAURANT_OIL: {
    OIL_SMOKE_EVENT: '10127',    // 餐饮油烟事件
    OIL_SMOKE_ALERT: '20102',    // 餐饮油烟告警
    RESTAURANT_FACILITY: '399',  // 餐饮企业
  },
  
  // 环卫行业相关 (示例，根据实际业务填写)
  ENVIRONMENT: {
    SANITATION_EVENT: '20201',   // 环卫事件
    SANITATION_ALERT: '20202',   // 环卫告警
    SANITATION_FACILITY: '499',  // 环卫设施
  },
  
  // 其他行业可以按照相同模式添加
};

// 网格类型常量
export const GRID_TYPE = {
  // 餐饮油烟相关
  RESTAURANT_OIL: {
    OIL_SMOKE_EVENT: '02',       // 油烟事件网格类型
    RESTAURANT_FACILITY: '09',   // 餐饮企业网格类型
  },
  
  // 环卫行业相关 (示例，根据实际业务填写)
  ENVIRONMENT: {
    SANITATION_EVENT: '03',      // 环卫事件网格类型
    SANITATION_FACILITY: '10',   // 环卫设施网格类型
  },
};

// 面板激活规则
export const PANEL_ACTIVATION = {
  // 哪些数据类型会激活左侧面板
  ACTIVATE_LEFT: [
    DATA_TYPE.RESTAURANT_OIL.OIL_SMOKE_ALERT,
    DATA_TYPE.RESTAURANT_OIL.RESTAURANT_FACILITY,
  ],
  
  // 哪些数据类型会激活右侧面板
  ACTIVATE_RIGHT: [
    DATA_TYPE.RESTAURANT_OIL.OIL_SMOKE_EVENT,
  ],
  
  // 哪些数据类型不改变激活状态
  PRESERVE_ACTIVE: [
    // DATA_TYPE.RESTAURANT_OIL.RESTAURANT_FACILITY, // 移除，已添加到ACTIVATE_LEFT
  ],
};

// 数据类型到网格类型的映射
export const DATA_TO_GRID_TYPE_MAP: Record<string, string> = {
  [DATA_TYPE.RESTAURANT_OIL.OIL_SMOKE_EVENT]: GRID_TYPE.RESTAURANT_OIL.OIL_SMOKE_EVENT,
  [DATA_TYPE.RESTAURANT_OIL.OIL_SMOKE_ALERT]: GRID_TYPE.RESTAURANT_OIL.OIL_SMOKE_EVENT, // 告警使用相同的网格类型
  [DATA_TYPE.RESTAURANT_OIL.RESTAURANT_FACILITY]: GRID_TYPE.RESTAURANT_OIL.RESTAURANT_FACILITY,
  // 其他映射关系
};

// 行业默认页面IDs
export const INDUSTRY_PAGE_IDS = {
  RESTAURANT_OIL: 'restaurantOil',
  ENVIRONMENT: 'environment',
  // 其他行业页面ID
};

// 页面默认数据类型
export const PAGE_DEFAULT_DATA_TYPES: Record<string, string> = {
  'home': DATA_TYPE.RESTAURANT_OIL.OIL_SMOKE_EVENT,
  'restaurantOil': DATA_TYPE.RESTAURANT_OIL.OIL_SMOKE_EVENT,
  'environment': DATA_TYPE.ENVIRONMENT.SANITATION_EVENT,
  // 更多页面默认数据类型
};

// 区域代码
export const REGION_CODES = {
  CHENGDU: '5101',
  // 其他常用区域代码
}; 