import React, { useEffect, useState } from 'react';
import styles from './index.less';
import notificationIcon from '@/assets/images/V-2504/map-notification-bg.png';

interface NotificationItem {
  id: string;
  content: string;
}

interface MapNotificationProps {
  districtName?: string;
}

const MapNotification: React.FC<MapNotificationProps> = ({ districtName = '金牛区' }) => {
  const [visible, setVisible] = useState(true);
  const [currentIndex, setCurrentIndex] = useState(0);
  
  // 通知消息列表
  const notifications: NotificationItem[] = [
    { id: '1', content: '新增一次餐饮油烟告警' },
    { id: '2', content: '新增一件餐饮油烟事件' },
  ];

  const showTime = 5000; // 显示showTime秒
  const hideTime = 5000; // 隐藏hideTime秒

  useEffect(() => {
    let timer: NodeJS.Timeout;

    const showNotification = () => {
      setVisible(true);
      // showTime后隐藏
      timer = setTimeout(() => {
        setVisible(false);
        // hideTime后显示下一条
        timer = setTimeout(() => {
          setCurrentIndex((prevIndex) => (prevIndex + 1) % notifications.length);
          showNotification();
        }, hideTime);
      }, showTime);
    };

    // 启动第一条通知的显示
    showNotification();

    return () => {
      if (timer) {
        clearTimeout(timer);
      }
    };
  }, []);

  // 如果不可见，返回null
  if (!visible) {
    return null;
  }

  return (
    <div className={styles.notificationBar}>
      <div className={styles.content}>
        <img src={notificationIcon} className={styles.icon} alt="通知" />
        <span className={styles.district}>{districtName}</span>
        <span className={styles.message}>{notifications[currentIndex].content}</span>
      </div>
    </div>
  );
};

export default MapNotification; 