/**
 * 环境配置工具
 * 根据不同环境返回不同的配置
 */

interface EnvConfig {
  wsUrl: string;
  apiBaseUrl: string;
  // 可扩展其他环境配置
}

// 开发/测试环境配置
const devConfig: EnvConfig = {
  wsUrl: 'ws://171.217.92.33:21601/city-operation/movement-sensor-event/websocket',
  apiBaseUrl: '/api',
};

// 生产环境配置
const prodConfig: EnvConfig = {
  wsUrl: 'wss://cdcgzgf.cn:13200/city-operation/movement-sensor-event/websocket',
  apiBaseUrl: '/api',
};

/**
 * 获取当前环境的配置
 */
export const getEnvConfig = (): EnvConfig => {
  const env = process.env.NODE_ENV;
  if (env === 'production') {
    return prodConfig;
  }
  return devConfig;
}; 